@@ -13,7 +13,16 @@ MCMCfunction = function(nn,PP,KK,dd,XX,YY,ZZ,TT,beta,intercept,alpha,MuAlpha,Sig
     postVar = postMu = rep(0,niter*(PP+1))
     likelihood = rep(0,niter)
 
-    out = .C('sampleRandomIntervention',as.integer(niter),as.double(XX),as.double(YY),as.double(ZZ),as.integer(TT),as.integer(nn),as.integer(PP),as.integer(dd),as.integer(KK),as.double(beta),as.double(intercept),as.double(alpha),as.double(MuAlpha),as.double(SigmaAlpha),as.double(MuBeta),as.double(SigmaBeta),as.double(MuZ),as.double(VarZ),as.double(tuneBetaAll),as.double(tuneInt),as.double(tuneAlpha),as.double(tuneZAll),as.double(accBetaAll),as.double(accAlpha),as.double(accIntAll),as.double(accZAll),as.double(betaFinal),as.double(AlphaFinal),as.double(ZZFinal),as.double(InterceptFinal),as.double(Zvar1),as.double(Zvar2),as.double(postVar),as.double(postMu),as.double(likelihood),as.double(PriorA),as.double(PriorB),as.integer(intervention),dup = FALSE)
+    out = .C('sampleRandomIntervention',as.integer(niter),as.double(XX),as.double(YY),
+             as.double(ZZ),as.integer(TT),as.integer(nn),as.integer(PP),as.integer(dd),
+             as.integer(KK),as.double(beta),as.double(intercept),as.double(alpha),
+             as.double(MuAlpha),as.double(SigmaAlpha),as.double(MuBeta),as.double(SigmaBeta),
+             as.double(MuZ),as.double(VarZ),as.double(tuneBetaAll),as.double(tuneInt),
+             as.double(tuneAlpha),as.double(tuneZAll),as.double(accBetaAll),as.double(accAlpha),
+             as.double(accIntAll),as.double(accZAll),as.double(betaFinal),as.double(AlphaFinal),
+             as.double(ZZFinal),as.double(InterceptFinal),as.double(Zvar1),as.double(Zvar2),
+             as.double(postVar),as.double(postMu),as.double(likelihood),as.double(PriorA),
+             as.double(PriorB),as.integer(intervention))
 
     betaFinal = array(out[[27]],dim = c(niter,PP,KK ))
     AlphaFinal = array(out[[28]],dim = c(niter,1) )
