@@ -16,7 +16,16 @@ MCMCfixedEF = function(nn,PP,KK,dd,XX,YY,ZZ,TT,
     Zvar1 = Zvar2= rep(0, niter)
     likelihood = rep(0,niter)
 
-    out = .C('sampleFixedIntervention',as.integer(niter), as.double(XX), as.double(YY), as.double(ZZ), as.integer(TT), as.integer(nn), as.integer(PP), as.integer(dd), as.integer(KK), as.double(beta), as.double(intercept), as.double(alpha), as.double(MuAlpha), as.double(SigmaAlpha), as.double(MuBeta), as.double(SigmaBeta), as.double(MuZ), as.double(VarZ), as.double(tuneBetaAll), as.double(tuneInt),as.double(tuneAlpha), as.double(tuneZAll), as.double(accBetaAll), as.double(accAlpha), as.double(accIntAll),as.double(accZAll), as.double(betaFinal), as.double(AlphaFinal), as.double(ZZFinal), as.double(InterceptFinal),as.double(Zvar1), as.double(Zvar2),as.double(likelihood),as.double(PriorA),as.double(PriorB), as.integer(intervention))
+    out = .C('sampleFixedIntervention',as.integer(niter), 
+             as.double(XX), as.double(YY), as.double(ZZ), as.integer(TT),
+             as.integer(nn), as.integer(PP), as.integer(dd), as.integer(KK),
+             as.double(beta), as.double(intercept), as.double(alpha), 
+             as.double(MuAlpha), as.double(SigmaAlpha), as.double(MuBeta), 
+             as.double(SigmaBeta), as.double(MuZ), as.double(VarZ), as.double(tuneBetaAll), 
+             as.double(tuneInt),as.double(tuneAlpha), as.double(tuneZAll), as.double(accBetaAll), 
+             as.double(accAlpha), as.double(accIntAll),as.double(accZAll), as.double(betaFinal), 
+             as.double(AlphaFinal), as.double(ZZFinal), as.double(InterceptFinal),as.double(Zvar1),
+             as.double(Zvar2),as.double(likelihood),as.double(PriorA),as.double(PriorB), as.integer(intervention))
 
     betaFinal = array(out[[27]],dim = c(niter,PP,1))
     AlphaFinal = array(out[[28]],dim = c(niter,1) )
